@@ -18,7 +18,6 @@ def _skip_to(f, char):
     c = None
     while c != char:
         c = f.read(1).decode()
-    return
 
 
 def _skip_close(f, num_open_brackets):
@@ -28,7 +27,6 @@ def _skip_close(f, num_open_brackets):
             num_open_brackets += 1
         elif char == ")":
             num_open_brackets -= 1
-    return
 
 
 def _read_points(f, line, first_point_index_overall, last_point_index):
@@ -39,6 +37,7 @@ def _read_points(f, line, first_point_index_overall, last_point_index):
 
     # (3010 (zone-id first-index last-index type ND)
     out = re.match("\\s*\\(\\s*(|20|30)10\\s*\\(([^\\)]*)\\).*", line)
+    assert out is not None
     a = [int(num, 16) for num in out.group(2).split()]
 
     if len(a) <= 4:
@@ -100,6 +99,7 @@ def _read_cells(f, line):
         return None, None
 
     out = re.match("\\s*\\(\\s*(|20|30)12\\s*\\(([^\\)]+)\\).*", line)
+    assert out is not None
     a = [int(num, 16) for num in out.group(2).split()]
     if len(a) <= 4:
         raise ReadError()
@@ -187,6 +187,7 @@ def _read_faces(f, line):
         return {}
 
     out = re.match("\\s*\\(\\s*(|20|30)13\\s*\\(([^\\)]+)\\).*", line)
+    assert out is not None
     a = [int(num, 16) for num in out.group(2).split()]
 
     if len(a) <= 4:
